
#include <avr/pgmspace.h>      //save SRAM by putting strings in FLASH
#include <SoftwareSerial.h>
#include "shieldA_lib.h"
#include "MemoryFree.h"


//-----------------------------------------------------------------------------
// GLOBALS --------------------------------------------------------------------
//-----------------------------------------------------------------------------

unsigned long time;                //program run time
int ret;

void debug2(String cmd, int ret) {
  debug_print( cmd,                         LEVEL_DEBUG, 1, 1 );
  debug_printP( PSTR(" ---> CMD RET --->: "), LEVEL_DEBUG, 1, 0 );
  debug_print ( String(ret),                LEVEL_DEBUG, 0, 1);
  util_printBuffer();
}


//-----------------------------------------------------------------------------
// SETUP ----------------------------------------------------------------------
//-----------------------------------------------------------------------------

void setup() {
  mySerial.begin(115200);
  mySerial.println("");

  glob_debug = 5;                  //Override global debug print level 

  cmd_setup();                     //set-up shield GPIO
  cmd_power();                     //power on
  cmd_connection();                //check cellular connection
}


//-----------------------------------------------------------------------------
// LOOP -----------------------------------------------------------------------
//-----------------------------------------------------------------------------

void loop() {
    
  //DEBUG LOOP STATEMENT
  debug_printP( PSTR("--- LOOP ---"),   LEVEL_DEBUG, 1, 1 );

  util_time();
  
  //DEBUG FREE MEMORY - (A VALUABLE RESOURCE!!!... which is why we're using PROGMEM)
  debug_printP( PSTR("FREE MEMORY()="), LEVEL_DEBUG, 1, 0 );
  debug_print( String(freeMemory()),    LEVEL_DEBUG, 0, 1 );
  
  //-----
  
  //BASIC WEB QUERY
  //Nickname                                               //at command         //Description
  
  ret = at_ate0();                                         //                   //diable echo to save space in buffer
  debug2 ("WEBOPEN", ret);
  util_clearBuffer();
  
  util_time();
  ret = at_zipcallOpen();                                  //at_webopen         //start call - state 1 open
  debug2 ("WEBOPEN", ret);
  util_clearBuffer();
  
  util_time();
  ret = at_zipopen(1,0,"www.dbunplugged.com",9999);        //at_websetup        //socket id,type(UDP=1,TCP=0),hostname/IP,Port
  debug2 ("WEBSETUP", ret);
  util_clearBuffer();
  
  util_time();
  ret = at_zipsend(1);                                     //at_websend         //send data
  debug2 ("WEBSEND", ret);
  util_clearBuffer();
  
  util_time();
  String msg = "/put/<username>/<password>/testNum/1/testStr/TCP";
  //String msg = "GET " + msgURL + " HTTP/1.1\r\nHost: www.dbunplugged.com\r\n\r\n";  //this string would be used for port 80, web request
  
  ret = at_zipwrite(msg);                                  //at_webmsg
  debug2 ("WEBMSG", ret);
  //Parse the HTML response, removing the header and leaving the body
  //cmd_parseHtmlResponse();
  util_clearBuffer();
  
  util_time();
  ret = at_zipcallClose();                                 //at_webclose        //stop call - state 0 close
  debug2 ("WEBCLOSE", ret);
  util_clearBuffer();


  delay(60000);
}
